Contacts
========

Feel free to contact the developers:
 - `Xuecheng Shao <https://sites.rutgers.edu/prg/people/xuecheng-shao/>`_
 - `Michele Pavanello <https://sasn.rutgers.edu/about-us/faculty-staff/michele-pavanello>`_
 - `Jessica Martinez <https://sites.rutgers.edu/prg/people/jessica-martinez/>`_ 
 - `Md Rajib Khan Musa <https://sites.rutgers.edu/prg/people/rajib-musa-kahn/>`_
 - `Lukas Paetow <https://www.uni-muenster.de/Chemie.oc/neugebauer/group.html>`_

GitLab
------

Find out more about the `Pavanello Research Group <http://sites.rutgers.edu/prg>`_. 

Feel free to create new issues, merge requests or fork your own `QMLearn` on QMLearn's `GitLab` page: 

 - `GitLab <https://gitlab.com/pavanello-research-group/qmlearn>`_

Credits
-------
QMLearn is developed in collaboration with `Mark Tuckerman @ NYU <https://as.nyu.edu/content/nyu-as/as/faculty/mark-e-tuckerman.html>`_ and is supported by NSF, grant number CHE-2154760.
